<?php

namespace Asadi\Career\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Asadi\Career\Interfaces\CareerRepositoryInterface;
use Asadi\Career\Repositories\Presenter\CareerItemTransformer;

/**
 * Pubic API controller class.
 */
class CareerPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Asadi\Career\Interfaces\CareerRepositoryInterface $career
     *
     * @return type
     */
    public function __construct(CareerRepositoryInterface $career)
    {
        $this->repository = $career;
        parent::__construct();
    }

    /**
     * Show career's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $careers = $this->repository
            ->setPresenter('\\Asadi\\Career\\Repositories\\Presenter\\CareerListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $careers['code'] = 2000;
        return response()->json($careers)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show career.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $career = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($career)) {
            $career         = $this->itemPresenter($module, new CareerItemTransformer);
            $career['code'] = 2001;
            return response()->json($career)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
