<?php

namespace Asadi\Career\Http\Controllers\Api;

use App\Http\Controllers\Api\UserController as BaseController;
use Asadi\Career\Http\Requests\CareerRequest;
use Asadi\Career\Interfaces\CareerRepositoryInterface;
use Asadi\Career\Models\Career;

/**
 * User API controller class.
 */
class CareerUserController extends BaseController
{
    /**
     * Initialize career controller.
     *
     * @param type CareerRepositoryInterface $career
     *
     * @return type
     */
    public function __construct(CareerRepositoryInterface $career)
    {
        $this->repository = $career;
        $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->pushCriteria(new \Asadi\Career\Repositories\Criteria\CareerUserCriteria());
        parent::__construct();
    }

    /**
     * Display a list of career.
     *
     * @return json
     */
    public function index(CareerRequest $request)
    {
        $careers  = $this->repository
            ->setPresenter('\\Asadi\\Career\\Repositories\\Presenter\\CareerListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $careers['code'] = 2000;
        return response()->json($careers) 
            ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display career.
     *
     * @param Request $request
     * @param Model   Career
     *
     * @return Json
     */
    public function show(CareerRequest $request, Career $career)
    {

        if ($career->exists) {
            $career         = $career->presenter();
            $career['code'] = 2001;
            return response()->json($career)
                ->setStatusCode(200, 'SHOW_SUCCESS');;
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }

    /**
     * Show the form for creating a new career.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(CareerRequest $request, Career $career)
    {
        $career         = $career->presenter();
        $career['code'] = 2002;
        return response()->json($career)
            ->setStatusCode(200, 'CREATE_SUCCESS');
    }

    /**
     * Create new career.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(CareerRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $career          = $this->repository->create($attributes);
            $career          = $career->presenter();
            $career['code']  = 2004;

            return response()->json($career)
                ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message' => $e->getMessage(),
                'code'    => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
        }

    }

    /**
     * Show career for editing.
     *
     * @param Request $request
     * @param Model   $career
     *
     * @return json
     */
    public function edit(CareerRequest $request, Career $career)
    {
        if ($career->exists) {
            $career         = $career->presenter();
            $career['code'] = 2003;
            return response()-> json($career)
                ->setStatusCode(200, 'EDIT_SUCCESS');;
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }
    }

    /**
     * Update the career.
     *
     * @param Request $request
     * @param Model   $career
     *
     * @return json
     */
    public function update(CareerRequest $request, Career $career)
    {
        try {

            $attributes = $request->all();

            $career->update($attributes);
            $career         = $career->presenter();
            $career['code'] = 2005;

            return response()->json($career)
                ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the career.
     *
     * @param Request $request
     * @param Model   $career
     *
     * @return json
     */
    public function destroy(CareerRequest $request, Career $career)
    {

        try {

            $t = $career->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('career::career.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
