<?php

namespace Asadi\Career\Http\Controllers;

use App\Http\Controllers\UserController as BaseController;
use Form;
use Asadi\Career\Http\Requests\CareerRequest;
use Asadi\Career\Interfaces\CareerRepositoryInterface;
use Asadi\Career\Models\Career;

class CareerUserController extends BaseController
{
    /**
     * Initialize career controller.
     *
     * @param type CareerRepositoryInterface $career
     *
     * @return type
     */
    public function __construct(CareerRepositoryInterface $career)
    {
        $this->repository = $career;
        $this->repository
                ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
                ->pushCriteria(new \Asadi\Career\Repositories\Criteria\CareerUserCriteria());
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(CareerRequest $request)
    {
        $careers = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        $this->theme->prependTitle(trans('career::career.names'));

        return $this->theme->of('career::user.career.index', compact('careers'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param Career $career
     *
     * @return Response
     */
    public function show(CareerRequest $request, Career $career)
    {
        Form::populate($career);

        return $this->theme->of('career::user.career.show', compact('career'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(CareerRequest $request)
    {

        $career = $this->repository->newInstance([]);
        Form::populate($career);

        $this->theme->prependTitle(trans('career::career.names'));
        return $this->theme->of('career::user.career.create', compact('career'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CareerRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $career = $this->repository->create($attributes);

            return redirect(trans_url('/user/career/career'))
                -> with('message', trans('messages.success.created', ['Module' => trans('career::career.name')]))
                -> with('code', 201);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param Career $career
     *
     * @return Response
     */
    public function edit(CareerRequest $request, Career $career)
    {

        Form::populate($career);
        $this->theme->prependTitle(trans('career::career.names'));

        return $this->theme->of('career::user.career.edit', compact('career'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param Career $career
     *
     * @return Response
     */
    public function update(CareerRequest $request, Career $career)
    {
        try {
            $this->repository->update($request->all(), $career->getRouteKey());

            return redirect(trans_url('/user/career/career'))
                ->with('message', trans('messages.success.updated', ['Module' => trans('career::career.name')]))
                ->with('code', 204);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(CareerRequest $request, Career $career)
    {
        try {
            $this->repository->delete($career->getRouteKey());
            return redirect(trans_url('/user/career/career'))
                ->with('message', trans('messages.success.deleted', ['Module' => trans('career::career.name')]))
                ->with('code', 204);

        } catch (Exception $e) {

            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);

        }
    }
}
