<?php

namespace Asadi\Career\Http\Controllers;
use Litepie\Career\Http\Requests\CareerRequest;
use Litepie\Career\Models\Career;

trait CareerWorkflow {
	
    /**
     * Workflow controller function for career.
     *
     * @param Model   $career
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(CareerRequest $request, Career $career, $step)
    {

        try {

            $career->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('career::career.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/career/career/' . $career->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/career/career/' . $career->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for career.
     *
     * @param Model   $career
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Career $career, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $career->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('career::career.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('career::admin.career.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('career::admin.career.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('career::admin.career.message', $data)->render();

        }

    }
}