<?php

namespace Asadi\Career\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Asadi\Career\Models\Career;

class CareerAction
{
    /**
     * Perform the complete action.
     *
     * @param Career $career
     *
     * @return Career
     */
    public function complete(Career $career)
    {
        try {
            $career->status = 'complete';
            return $career->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Career $career
     *
     * @return Career
     */public function verify(Career $career)
    {
        try {
            $career->status = 'verify';
            return $career->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Career $career
     *
     * @return Career
     */public function approve(Career $career)
    {
        try {
            $career->status = 'approve';
            return $career->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Career $career
     *
     * @return Career
     */public function publish(Career $career)
    {
        try {
            $career->status = 'publish';
            return $career->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Career $career
     *
     * @return Career
     */
    public function archive(Career $career)
    {
        try {
            $career->status = 'archive';
            return $career->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Career $career
     *
     * @return Career
     */
    public function unpublish(Career $career)
    {
        try {
            $career->status = 'unpublish';
            return $career->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
