<?php

namespace Asadi\Career\Workflow;

use Asadi\Career\Models\Career;
use Validator;

class CareerValidator
{

    /**
     * Determine if the given career is valid for complete status.
     *
     * @param Career $career
     *
     * @return bool / Validator
     */
    public function complete(Career $career)
    {
        return Validator::make($career->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given career is valid for verify status.
     *
     * @param Career $career
     *
     * @return bool / Validator
     */
    public function verify(Career $career)
    {
        return Validator::make($career->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given career is valid for approve status.
     *
     * @param Career $career
     *
     * @return bool / Validator
     */
    public function approve(Career $career)
    {
        return Validator::make($career->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given career is valid for publish status.
     *
     * @param Career $career
     *
     * @return bool / Validator
     */
    public function publish(Career $career)
    {
        return Validator::make($career->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given career is valid for archive status.
     *
     * @param Career $career
     *
     * @return bool / Validator
     */
    public function archive(Career $career)
    {
        return Validator::make($career->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given career is valid for unpublish status.
     *
     * @param Career $career
     *
     * @return bool / Validator
     */
    public function unpublish(Career $career)
    {
        return Validator::make($career->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
